##  Tagging Mode
By choosing the Tagging Mode, you can control how users can add new Tags to Fact Sheets. There are three tagging modes:
  * On-the-fly tagging: All Workspace Members and Admins can create new tags directly in the Fact Sheet
  * Pre-defined tag groups OR On-the-fly tagging: For fact sheet types where tag groups are pre-defined by an Admin, on-the-fly tagging is disabled; otherwise, Members and Admins can create their tags on-the-fly
  * Pre-defined only: Only Admins can create tags


The drop-down menu provides options to choose the mode that suits your needs.
![Tagging Modes](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2756a38f7a441014bcb6c7fc9191dce3_LowRes.png)
Tagging Modes
For additional information, see [Tags](https://help.sap.com/docs/leanix/ea/tags?locale=en-US&state=PRODUCTION&version=CLOUD "Tags are labels used to classify and categorize fact sheets, making it easy to filter, organize, and analyze data. Learn how to assign and manage tags, understand when and when not to use them, as well as leverage them for filtering and reporting.").
**Tip**
On-the-fly tagging may result in the widespread use of unstructured tags, particularly during initial data loading or in distributed organizations. Therefore, we suggest defining Tag Groups that align with your objectives and setting the standard to "Pre-defined only."
